API_VERSION=4
API_HOST='api.luminoso.com'
URL_BASE='https://%s/v%d' % (API_HOST, API_VERSION)
